import { IpfsCID, MarketplaceTag, URLString, UnixTimestamp } from "../primitives/index.js";
export declare enum EQuestionnaireStatus {
    Available = 0,
    Complete = 1
}
export declare enum EQuestionnaireQuestionType {
    MultipleChoice = "MultipleChoice",
    Location = "Location",
    Text = "Text",
    Numeric = "Numeric"
}
export declare enum EQuestionnaireQuestionDisplayType {
    Dropdown = "Dropdown",
    List = "List",
    Scale = "Scale"
}
export declare class Questionnaire {
    /**I
     * The questionnaire is uniquely identified by it's CID in IPFS. This is the primary key for
     * questionnaires.
     */
    readonly id: IpfsCID;
    readonly marketplaceTag: MarketplaceTag;
    readonly status: EQuestionnaireStatus;
    readonly title: string;
    readonly description: string | null;
    readonly image: URLString | null;
    readonly questions: QuestionnaireQuestion[];
    constructor(
    /**I
     * The questionnaire is uniquely identified by it's CID in IPFS. This is the primary key for
     * questionnaires.
     */
    id: IpfsCID, // the location of the questionnaire in IPFS
    marketplaceTag: MarketplaceTag, // The tag that
    status: EQuestionnaireStatus, title: string, description: string | null, image: URLString | null, questions: QuestionnaireQuestion[]);
}
export declare class QuestionnaireWithAnswers extends Questionnaire {
    readonly answers: QuestionnaireAnswer[];
    measurementTime: UnixTimestamp;
    constructor(id: IpfsCID, marketplaceTag: MarketplaceTag, status: EQuestionnaireStatus, title: string, description: string | null, image: URLString | null, questions: QuestionnaireQuestion[], answers: QuestionnaireAnswer[], measurementTime: UnixTimestamp);
}
export declare class QuestionnaireQuestion {
    readonly index: number;
    readonly type: EQuestionnaireQuestionType;
    readonly text: string;
    readonly choices: string[] | number[] | null;
    readonly minimum: number | null;
    readonly maximum: number | null;
    readonly displayType: EQuestionnaireQuestionDisplayType | null;
    readonly multiSelect: boolean;
    readonly required: boolean;
    readonly lowerLabel: string | null;
    readonly upperLabel: string | null;
    constructor(index: number, type: EQuestionnaireQuestionType, text: string, choices: string[] | number[] | null, minimum: number | null, maximum: number | null, displayType: EQuestionnaireQuestionDisplayType | null, multiSelect?: boolean, required?: boolean, lowerLabel?: string | null, upperLabel?: string | null);
}
export declare class NewQuestionnaireAnswer {
    readonly questionnaireId: IpfsCID;
    readonly questionIndex: number;
    readonly choice: number | string | number[] | string[];
    constructor(questionnaireId: IpfsCID, questionIndex: number, choice: number | string | number[] | string[]);
}
export declare class QuestionnaireAnswer extends NewQuestionnaireAnswer {
    readonly questionnaireId: IpfsCID;
    readonly questionIndex: number;
    readonly choice: number | string | number[] | string[];
    constructor(questionnaireId: IpfsCID, questionIndex: number, choice: number | string | number[] | string[]);
}
//# sourceMappingURL=Questionnaire.d.ts.map